@@ -1,6 +1,5 @@
-context("Make and print a summary of a skim object")
-
 test_that("Summary creates the correct summary object", {
+  withr::local_options(list(cli.unicode = FALSE))
   # Test it creates the correct 4 parts
   skim_input <- skim(iris)
   summary_input <- summary(skim_input)
@@ -15,6 +14,7 @@ test_that("Summary creates the correct summary object", {
 
 test_that("The summary print method prints the correct object", {
   skip_if_not(l10n_info()$`UTF-8`)
+  withr::local_options(list(cli.unicode = FALSE))
   skim_summary_input <- summary(skim(iris))
   expect_known_output(
     skim_summary_input, "summary/summary_iris.txt",
@@ -25,6 +25,7 @@ test_that("The summary print method prints the correct object", {
 
 test_that("The summary print method prints the correct object when piped", {
   skip_if_not(l10n_info()$`UTF-8`)
+  withr::local_options(list(cli.unicode = FALSE))
   # Test that the correct lines are output, no name should be output.
   summary_input <- iris %>%
     skim() %>%
